==> agefinder_1.0.0-1.tar.gz: agefinder-1.0.0/src/opt/agefinder/agefinder.py <==
#!/usr/bin/env python
import datetime
import sys
import pygtk
pygtk.require('2.0')
import gtk

y=int(datetime.date.today().strftime("%Y")[0:4])
m=int(datetime.date.today().strftime("%m")[0:2])
d=int(datetime.date.today().strftime("%d")[0:2])
day=0
month=0
year=0
age=0

class FirstWin:
    def __init__(self):
        self.win = gtk.Window(gtk.WINDOW_TOPLEVEL)
        self.win.connect("destroy", self.destroy)
        self.win.set_title('Age Finder')
	table = gtk.Table(rows=4,columns=3,homogeneous=True)
	self.win.add(table)     
        label = gtk.Label("<b><big>Insert date of birth</big></b>")
        label.set_use_markup(True)
	table.attach(label,0,3,0,1)
	label.show()
 	label = gtk.Label("Day")
 	table.attach(label,0,1,1,2)
 	label.show()
 	label = gtk.Label("Month")
 	table.attach(label,1,2,1,2)
 	label.show()
 	label = gtk.Label("Year")
 	table.attach(label,2,3,1,2)
 	label.show()
        
#comboboxday
 	combobox1 = gtk.combo_box_new_text()
 	for i in range(1,32):
  	    label = "%d" % i
        # Add item to the column
 	    combobox1.append_text(label)
	combobox1.connect("changed", self.getDay)
 	table.attach(combobox1,0,1,2,3)
 	combobox1.show()

        
#comboboxmonth
 	combobox2 = gtk.combo_box_new_text()
 	for i in range(1,13):
  	    label = "%d" % i
        # Add item to the column
 	    combobox2.append_text(label)
	combobox2.connect("changed", self.getMonth)
 	table.attach(combobox2,1,2,2,3)
 	combobox2.show()
	
#inserimento anno con gtk.Entry 
 	entry = gtk.Entry()
 	entry.set_text("Put year and press enter!")
 	entry.connect("activate", self.getUserInput)
 	table.attach(entry,2,3,2,3)
 	entry.show()

	
        button = gtk.Button("Find Age!")
        button.connect("clicked", self.showMessage, None)
	table.attach(button,1,2,3,4)
	button.show()
	
	table.show()
	self.win.show()
        

        
    
    def getUserInput(self, entry):
#legge anno inserito e lo assegna a variabile
	global year
        year = entry.get_text()

    def getDay(self, combobox1):
	global day
	day = combobox1.get_active()

    def getMonth(self, combobox2):
	global month
	month = combobox2.get_active()
        
    def showMessage(self, widget, data=None):
#apre dialogo con risultato
	
        if m >= month and d>=day:
            age=y-int(year)
        else:
            age=y-int(year)-1
        message = gtk.MessageDialog(None, gtk.DIALOG_MODAL, gtk.MESSAGE_INFO, gtk.BUTTONS_CLOSE, "The age is %d" % age)
	message.show()
	resp = message.run()
	if resp == gtk.RESPONSE_CLOSE:
	    message.destroy()

        
    def destroy(self, widget, data=None):
        return gtk.main_quit()
        
    def main(self):
        gtk.main()
        
if __name__ == "__main__":
    first = FirstWin()
    first.main()

==> agefinder_1.1.0-1.tar.gz: agefinder-1.1.0/src/opt/agefinder/agefinder.py <==
#!/usr/bin/env python

    #Copyright (C) 2013 Fabrizio Pasqualini
    #This program is free software: you can redistribute it and/or modify
    #it under the terms of the GNU General Public License as published by
    #the Free Software Foundation, either version 3 of the License, or
    #(at your option) any later version.
    #This program is distributed in the hope that it will be useful,
    #but WITHOUT ANY WARRANTY; without even the implied warranty of
    #MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    #GNU General Public License for more details.
    #You should have received a copy of the GNU General Public License
    #along with this program.  If not, see <http://www.gnu.org/licenses/>.

import datetime
import sys
import pygtk
pygtk.require('2.0')
import gtk

y=datetime.date.today().year
m=datetime.date.today().month
d=datetime.date.today().day


class FirstWin:
    def __init__(self):
        self.win = gtk.Window(gtk.WINDOW_TOPLEVEL)
        self.win.connect("destroy", self.destroy)
        self.win.set_title('Age Finder')
	table = gtk.Table(rows=4,columns=3,homogeneous=True)
	self.win.add(table)     
        label = gtk.Label("<b><big>Insert date of birth</big></b>")
        label.set_use_markup(True)
	table.attach(label,0,3,0,1)
	label.show()
 	label = gtk.Label("Day")
 	table.attach(label,0,1,1,2)
 	label.show()
 	label = gtk.Label("Month")
 	table.attach(label,1,2,1,2)
 	label.show()
 	label = gtk.Label("Year")
 	table.attach(label,2,3,1,2)
 	label.show()
        
#comboboxday
 	combobox1 = gtk.combo_box_new_text()
 	for i in range(1,32):
  	    label = "%d" % i
        # Add item to the column
 	    combobox1.append_text(label)
	combobox1.connect("changed", self.getDay)
 	table.attach(combobox1,0,1,2,3)
 	combobox1.show()

        
#comboboxmonth
 	combobox2 = gtk.combo_box_new_text()
 	for i in range(1,13):
  	    label = "%d" % i
        # Add item to the column
 	    combobox2.append_text(label)
	combobox2.connect("changed", self.getMonth)
 	table.attach(combobox2,1,2,2,3)
 	combobox2.show()
	
#getting the year with gtk.Entry 
 	entry = gtk.Entry()
 	entry.set_text("Put year and press enter!")
 	entry.connect("activate", self.getUserInput)
 	table.attach(entry,2,3,2,3)
 	entry.show()

#button	
        button = gtk.Button("Find Age!")
        button.connect("clicked", self.showMessage, None)
	table.attach(button,1,2,3,4)
	button.show()
	
	table.show()
	self.win.show()
        

        
#reading values and assign to variables
    def getUserInput(self, entry):
	global year
        year = entry.get_text()

    def getDay(self, combobox1):
	global day
	day = combobox1.get_active()

    def getMonth(self, combobox2):
	global month
	month = combobox2.get_active()

#show dialog with the result        
    def showMessage(self, widget, data=None):

        if m > int(month):
            age=y-int(year)
        elif m == int(month) and d >= int(day):
            age=y-int(year)
        elif m == int(month) and d < int(day):
            age=y-int(year)-1
        else:
            age=y-int(year)-1
        message = gtk.MessageDialog(None, gtk.DIALOG_MODAL, gtk.MESSAGE_INFO, gtk.BUTTONS_CLOSE, "The age is %d" % age)
	message.show()
	resp = message.run()
	if resp == gtk.RESPONSE_CLOSE:
	    message.destroy()

        
    def destroy(self, widget, data=None):
        return gtk.main_quit()
        
    def main(self):
        gtk.main()
        
if __name__ == "__main__":
    first = FirstWin()
    first.main()
